@@ -1,3 +1,4 @@
+{-# OPTIONS_GHC -fno-warn-missing-signatures #-}
 -----------------------------------------------------------------------------
 -- |
 -- Module      : System.Taffybar
@@ -38,6 +39,7 @@ module System.Taffybar
   -- configuration might look like (also see "System.Taffybar.Example"):
   --
   -- > {-# LANGUAGE OverloadedStrings #-}
+  -- > import Data.Default (def)
   -- > import System.Taffybar
   -- > import System.Taffybar.Information.CPU
   -- > import System.Taffybar.SimpleConfig
@@ -50,13 +52,14 @@ module System.Taffybar
   -- >   return [ totalLoad, systemLoad ]
   -- >
   -- > main = do
-  -- >   let cpuCfg = defaultGraphConfig { graphDataColors = [ (0, 1, 0, 1), (1, 0, 1, 0.5)]
-  -- >                                   , graphLabel = Just "cpu"
-  -- >                                   }
-  -- >       clock = textClockNewWith defaultClockConfig
+  -- >   let cpuCfg = def
+  -- >                  { graphDataColors = [ (0, 1, 0, 1), (1, 0, 1, 0.5)]
+  -- >                  , graphLabel = Just "cpu"
+  -- >                  }
+  -- >       clock = textClockNewWith def
   -- >       cpu = pollingGraphNew cpuCfg 0.5 cpuCallback
-  -- >       workspaces = workspacesNew defaultWorkspacesConfig
-  -- >       simpleConfig = defaultSimpleTaffyConfig
+  -- >       workspaces = workspacesNew def
+  -- >       simpleConfig = def
   -- >                        { startWidgets = [ workspaces ]
   -- >                        , endWidgets = [ sniTrayNew, clock, cpu ]
   -- >                        }
@@ -142,11 +145,8 @@ import           Paths_taffybar ( getDataDir )
 -- | The parameters that are passed to Dyre when taffybar is invoked with
 -- 'dyreTaffybar'.
 taffybarDyreParams =
-  Dyre.defaultParams
-  { Dyre.projectName = "taffybar"
-  , Dyre.realMain = dyreTaffybarMain
-  , Dyre.showError = showError
-  , Dyre.ghcOpts = ["-threaded", "-rtsopts"]
+  (Dyre.newParams "taffybar" dyreTaffybarMain showError)
+  { Dyre.ghcOpts = ["-threaded", "-rtsopts"]
   , Dyre.rtsOptsHandling = Dyre.RTSAppend ["-I0", "-V0"]
   }
 
@@ -158,6 +158,7 @@ dyreTaffybar = Dyre.wrapMain taffybarDyreParams
 showError :: TaffybarConfig -> String -> TaffybarConfig
 showError cfg msg = cfg { errorMsg = Just msg }
 
+-- | The main function that should be run by dyre given a TaffybarConfig.
 dyreTaffybarMain :: TaffybarConfig -> IO ()
 dyreTaffybarMain cfg =
   case errorMsg cfg of
@@ -172,7 +173,7 @@ getDataFile name = do
   return (dataDir </> name)
 
 startCSS :: [FilePath] -> IO Gtk.CssProvider
-startCSS cssPaths = do
+startCSS cssFilePaths = do
   -- Override the default GTK theme path settings.  This causes the
   -- bar (by design) to ignore the real GTK theme and just use the
   -- provided minimal theme to set the background and text colors.
@@ -183,7 +184,7 @@ startCSS cssPaths = do
         doesFileExist filePath >>=
         flip when (Gtk.cssProviderLoadFromPath taffybarProvider (T.pack filePath))
 
-  mapM_ loadIfExists cssPaths
+  mapM_ loadIfExists cssFilePaths
 
   Just scr <- Gdk.screenGetDefault
   Gtk.styleContextAddProviderForScreen scr taffybarProvider 800
@@ -197,23 +198,26 @@ getDefaultCSSPaths = do
   defaultUserConfig <- getTaffyFile "taffybar.css"
   return [defaultUserConfig]
 
--- | Start taffybar with the provided 'TaffybarConfig'. Because this function
--- will not handle recompiling taffybar automatically when taffybar.hs is
--- updated, it is generally recommended that end users use 'dyreTaffybar'
--- instead. If automatic recompilation is handled by another mechanism such as
--- stack or a custom user script or not desired for some reason, it is
--- perfectly fine to use this function.
+-- | Start taffybar with the provided 'TaffybarConfig'. This function will not
+-- handle recompiling taffybar automatically when taffybar.hs is updated. If you
+-- would like this feature, use 'dyreTaffybar' instead. If automatic
+-- recompilation is handled by another mechanism such as stack or a custom user
+-- script or not desired for some reason, it is perfectly fine (and probably
+-- better) to use this function.
 startTaffybar :: TaffybarConfig -> IO ()
 startTaffybar config = do
-  updateGlobalLogger "" $ removeHandler
+  updateGlobalLogger "" removeHandler
   setTaffyLogFormatter "System.Taffybar"
   setTaffyLogFormatter "StatusNotifier"
   _ <- initThreads
   _ <- Gtk.init Nothing
   GIThreading.setCurrentThreadAsGUIThread
   defaultCSS <- getDataFile "taffybar.css"
-  cssPaths <- maybe getDefaultCSSPaths (return . return) $ cssPath config
-  _ <- startCSS $ defaultCSS:cssPaths
+  cssPathsToLoad <-
+    if null $ cssPaths config
+    then getDefaultCSSPaths
+    else return $ cssPaths config
+  _ <- startCSS $ defaultCSS:cssPathsToLoad
   _ <- buildContext config
 
   Gtk.main
