@@ -7,20 +7,26 @@
 -- Maintainer  : Ivan A. Malison
 -- Stability   : unstable
 -- Portability : unportable
+--
+-- This module defines a simpler, but less flexible config system than the one
+-- offered in "System.Taffybar.Context".
 -----------------------------------------------------------------------------
 module System.Taffybar.SimpleConfig
   ( SimpleTaffyConfig(..)
   , Position(..)
   , defaultSimpleTaffyConfig
+  , simpleDyreTaffybar
   , simpleTaffybar
   , toTaffyConfig
   , useAllMonitors
   , usePrimaryMonitor
+  , StrutSize(..)
   ) where
 
 import qualified Control.Concurrent.MVar as MV
 import           Control.Monad
 import           Control.Monad.Trans.Class
+import           Data.Default (Default(..))
 import           Data.List
 import           Data.Maybe
 import           Data.Unique
@@ -33,33 +39,33 @@ import qualified System.Taffybar.Context as BC (BarConfig(..), TaffybarConfig(..
 import           System.Taffybar.Context hiding (TaffybarConfig(..), BarConfig(..))
 import           System.Taffybar.Util
 
--- | The side of the monitor at which taffybar should be displayed.
+-- | An ADT representing the edge of the monitor along which taffybar should be
+-- displayed.
 data Position = Top | Bottom deriving (Show, Eq)
 
 -- | A configuration object whose interface is simpler than that of
 -- 'TaffybarConfig'. Unless you have a good reason to use taffybar's more
--- advanced interface, you should stick to this one.
+-- advanced interface, you should stick to using this one.
 data SimpleTaffyConfig = SimpleTaffyConfig
   {
-  -- | The xinerama/xrandr monitor number to put the bar on (default: PrimaryMonitor)
+  -- | The monitor number to put the bar on (default: 'usePrimaryMonitor')
     monitorsAction :: TaffyIO [Int]
-  -- | Number of pixels to reserve for the bar
-  , barHeight :: Int
+  -- | Number of pixels to reserve for the bar (default: 30)
+  , barHeight :: StrutSize
   -- | Number of additional pixels to reserve for the bar strut (default: 0)
   , barPadding :: Int
-  -- | The position of the bar on the screen (default: Top)
+  -- | The position of the bar on the screen (default: 'Top')
   , barPosition :: Position
-  -- | The number of pixels between widgets
+  -- | The number of pixels between widgets (default: 5)
   , widgetSpacing :: Int
-  -- | Widget constructors whose output are placed at the beginning of the bar
+  -- | Widget constructors whose outputs are placed at the beginning of the bar
   , startWidgets :: [TaffyIO Gtk.Widget]
-  -- | Widget constructors whose output are placed in the center of the bar
+  -- | Widget constructors whose outputs are placed in the center of the bar
   , centerWidgets :: [TaffyIO Gtk.Widget]
-  -- | Widget constructors whose output are placed at the end of the bar
+  -- | Widget constructors whose outputs are placed at the end of the bar
   , endWidgets :: [TaffyIO Gtk.Widget]
-  -- | Optional path to CSS stylesheet (loaded in addition to stylesheet found
-  -- in XDG data directory).
-  , cssPath :: Maybe FilePath
+  -- | List of paths to CSS stylesheets that should be loaded at startup.
+  , cssPaths :: [FilePath]
   -- | Hook to run at taffybar startup.
   , startupHook :: TaffyIO ()
   }
@@ -70,24 +76,29 @@ data SimpleTaffyConfig = SimpleTaffyConfig
 defaultSimpleTaffyConfig :: SimpleTaffyConfig
 defaultSimpleTaffyConfig = SimpleTaffyConfig
   { monitorsAction = useAllMonitors
-  , barHeight = 30
+  , barHeight = ScreenRatio $ 1 / 27
   , barPadding = 0
   , barPosition = Top
   , widgetSpacing = 5
   , startWidgets = []
   , centerWidgets = []
   , endWidgets = []
-  , cssPath = Nothing
+  , cssPaths = []
   , startupHook = return ()
   }
 
+instance Default SimpleTaffyConfig where
+  def = defaultSimpleTaffyConfig
+
+-- | Convert a 'SimpleTaffyConfig' into a 'StrutConfig' that can be used with
+-- gtk-strut.
 toStrutConfig :: SimpleTaffyConfig -> Int -> StrutConfig
-toStrutConfig SimpleTaffyConfig { barHeight = size
+toStrutConfig SimpleTaffyConfig { barHeight = height
                                 , barPadding = padding
                                 , barPosition = pos
                                 } monitor =
   defaultStrutConfig
-  { strutHeight = ExactSize $ fromIntegral size
+  { strutHeight = height
   , strutYPadding = fromIntegral padding
   , strutXPadding = fromIntegral padding
   , strutAlignment = Center
@@ -114,11 +125,13 @@ toBarConfig config monitor = do
 
 newtype SimpleBarConfigs = SimpleBarConfigs (MV.MVar [(Int, BC.BarConfig)])
 
+-- | Convert a 'SimpleTaffyConfig' into a 'BC.TaffybarConfig' that can be used
+-- with 'startTaffybar' or 'dyreTaffybar'.
 toTaffyConfig :: SimpleTaffyConfig -> BC.TaffybarConfig
 toTaffyConfig conf =
-    defaultTaffybarConfig
+    def
     { BC.getBarConfigsParam = configGetter
-    , BC.cssPath = cssPath conf
+    , BC.cssPaths = cssPaths conf
     , BC.startupHook = startupHook conf
     }
   where
@@ -144,21 +157,28 @@ toTaffyConfig conf =
 
       lift $ MV.modifyMVar configsVar lookupAndUpdate
 
--- | Start taffybar using 'SimpleTaffybarConfig'.
+-- | Start taffybar using dyre with a 'SimpleTaffybarConfig'.
+simpleDyreTaffybar :: SimpleTaffyConfig -> IO ()
+simpleDyreTaffybar conf = dyreTaffybar $ toTaffyConfig conf
+
+-- | Start taffybar with a 'SimpleTaffybarConfig'.
 simpleTaffybar :: SimpleTaffyConfig -> IO ()
-simpleTaffybar conf = dyreTaffybar $ toTaffyConfig conf
+simpleTaffybar conf = startTaffybar $ toTaffyConfig conf
 
 getMonitorCount :: IO Int
 getMonitorCount =
-  fromIntegral <$> (screenGetDefault >>= maybe (return 0) (screenGetDisplay >=> displayGetNMonitors))
+  fromIntegral <$> (screenGetDefault >>= maybe (return 0)
+                    (screenGetDisplay >=> displayGetNMonitors))
 
--- | Display a taffybar window on all monitors.
+-- | Supply this value for 'monitorsAction' to display the taffybar window on
+-- all monitors.
 useAllMonitors :: TaffyIO [Int]
 useAllMonitors = lift $ do
   count <- getMonitorCount
   return [0..count-1]
 
--- | Display the taffybar window on the primary monitor.
+-- | Supply this value for 'monitorsAction' to display the taffybar window only
+-- on the primary monitor.
 usePrimaryMonitor :: TaffyIO [Int]
 usePrimaryMonitor =
   return . fromMaybe 0 <$> lift (withDefaultCtx getPrimaryOutputNumber)
