@@ -10,23 +10,26 @@
 -- Stability   : unstable
 -- Portability : unportable
 --
--- This module provides battery widgets using the UPower system
--- service.
---
--- Currently it reports only the first battery it finds. If it does not find a
--- battery, it just returns an obnoxious widget with warning text in it. Battery
--- hotplugging is not supported. These more advanced features could be supported
--- if there is interest.
+-- This module provides battery widgets that are queried using the UPower dbus
+-- service. To avoid duplicating all information requests for each battery
+-- widget displayed (if using a multi-head configuration or multiple battery
+-- widgets), these widgets use the "BroadcastChan" based system for receiving
+-- updates defined in "System.Taffybar.Information.Battery".
 -----------------------------------------------------------------------------
-module System.Taffybar.Widget.Battery ( textBatteryNew, batteryIconNew ) where
+module System.Taffybar.Widget.Battery
+  ( batteryIconNew
+  , textBatteryNew
+  , textBatteryNewWithLabelAction
+  ) where
 
 import           Control.Applicative
 import           Control.Monad
 import           Control.Monad.IO.Class
 import           Control.Monad.Trans.Reader
+import           Data.Default (Default(..))
 import           Data.Int (Int64)
 import qualified Data.Text as T
-import           GI.Gtk
+import           GI.Gtk as Gtk
 import           Prelude
 import           StatusNotifier.Tray (scalePixbufToSize)
 import           System.Taffybar.Context
@@ -34,6 +37,7 @@ import           System.Taffybar.Information.Battery
 import           System.Taffybar.Util
 import           System.Taffybar.Widget.Generic.AutoSizeImage
 import           System.Taffybar.Widget.Generic.ChannelWidget
+import           System.Taffybar.Widget.Util hiding (themeLoadFlags)
 import           Text.Printf
 import           Text.StringTemplate
 
@@ -85,19 +89,64 @@ formatBattInfo info fmt =
 -- string where $percentage$ is replaced with the percentage of battery
 -- remaining and $time$ is replaced with the time until the battery is fully
 -- charged/discharged.
-textBatteryNew
-  :: String -- ^ Display format
-  -> TaffyIO Widget
-textBatteryNew format = do
+textBatteryNew :: String -> TaffyIO Widget
+textBatteryNew format = textBatteryNewWithLabelAction labelSetter
+  where labelSetter label info = do
+          setBatteryStateClasses def label info
+          labelSetMarkup label $
+                         formatBattInfo (getBatteryWidgetInfo info) format
+
+data BatteryClassesConfig = BatteryClassesConfig
+  { batteryHighThreshold :: Double
+  , batteryLowThreshold :: Double
+  , batteryCriticalThreshold :: Double
+  }
+
+defaultBatteryClassesConfig :: BatteryClassesConfig
+defaultBatteryClassesConfig =
+  BatteryClassesConfig
+  { batteryHighThreshold = 80
+  , batteryLowThreshold = 20
+  , batteryCriticalThreshold = 5
+  }
+
+instance Default BatteryClassesConfig where
+  def = defaultBatteryClassesConfig
+
+setBatteryStateClasses ::
+  MonadIO m => BatteryClassesConfig -> Gtk.Label -> BatteryInfo -> m ()
+setBatteryStateClasses config label info = do
+  case batteryState info of
+    BatteryStateCharging -> addClassIfMissing "charging" label >>
+                            removeClassIfPresent "discharging" label
+    BatteryStateDischarging -> addClassIfMissing "discharging" label >>
+                               removeClassIfPresent "charging" label
+    _ -> removeClassIfPresent "charging" label >>
+         removeClassIfPresent "discharging" label
+
+  classIf "high" $ percentage >= batteryHighThreshold config
+  classIf "low" $ percentage <= batteryLowThreshold config
+  classIf "critical" $ percentage <= batteryCriticalThreshold config
+  where percentage = batteryPercentage info
+        classIf klass condition =
+          if condition
+          then addClassIfMissing klass label
+          else removeClassIfPresent klass label
+
+-- | Like `textBatteryNew` but provides a more general way to update the label
+-- widget. The argument provided is an action that is used to update the text
+-- label given a 'BatteryInfo' object describing the state of the battery.
+textBatteryNewWithLabelAction ::
+  (Gtk.Label -> BatteryInfo -> TaffyIO ()) -> TaffyIO Widget
+textBatteryNewWithLabelAction labelSetter = do
   chan <- getDisplayBatteryChan
   ctx <- ask
-  let getLabelText info = formatBattInfo (getBatteryWidgetInfo info) format
-      getBatteryInfoIO = runReaderT getDisplayBatteryInfo ctx
   liftIO $ do
-    label <- getLabelText <$> getBatteryInfoIO >>= labelNew . Just
-    let setMarkup text = postGUIASync $ labelSetMarkup label text
-        updateWidget = setMarkup . getLabelText
-    void $ onWidgetRealize label $ getLabelText <$> getBatteryInfoIO >>= setMarkup
+    label <- labelNew Nothing
+    let updateWidget =
+          postGUIASync . flip runReaderT ctx . labelSetter label
+    void $ onWidgetRealize label $
+         runReaderT getDisplayBatteryInfo ctx >>= updateWidget
     toWidget =<< channelWidgetNew label chan updateWidget
 
 themeLoadFlags :: [IconLookupFlags]
