@@ -4,12 +4,11 @@
 {-# LANGUAGE ScopedTypeVariables #-}
 -- | This widget listens on DBus for freedesktop notifications
 -- (<http://developer.gnome.org/notification-spec/>).  Currently it is
--- somewhat ugly, but the format is somewhat configurable.  A visual
--- overhaul of the widget is coming.
+-- somewhat ugly, but the format is somewhat configurable.
 --
 -- The widget only displays one notification at a time and
 -- notifications are cancellable.
-
+--
 -- The notificationDaemon thread handles new notifications
 -- and cancellation requests, adding or removing the notification
 -- to or from the queue. It additionally starts a timeout thread
@@ -35,6 +34,7 @@ import           Control.Monad ( forever, void )
 import           Control.Monad.IO.Class
 import           DBus
 import           DBus.Client
+import           Data.Default ( Default(..) )
 import           Data.Foldable
 import           Data.Int ( Int32 )
 import           Data.Map ( Map )
@@ -235,6 +235,9 @@ defaultNotificationConfig =
                      , notificationFormatter = defaultFormatter
                      }
 
+instance Default NotificationConfig where
+  def = defaultNotificationConfig
+
 -- | Create a new notification area with the given configuration.
 notifyAreaNew :: MonadIO m => NotificationConfig -> m Widget
 notifyAreaNew cfg = liftIO $ do
