@@ -19,6 +19,7 @@ module System.Taffybar.Widget.Windows where
 import           Control.Monad
 import           Control.Monad.Trans.Class
 import           Control.Monad.Trans.Reader
+import           Data.Default (Default(..))
 import           Data.Maybe
 import qualified Data.Text as T
 import           GI.GLib (markupEscapeText)
@@ -44,7 +45,8 @@ defaultGetMenuLabel window = do
 
 defaultGetActiveLabel :: TaffyIO T.Text
 defaultGetActiveLabel = do
-  label <- fromMaybe "" <$> (runX11Def Nothing getActiveWindow >>= traverse defaultGetMenuLabel)
+  label <- fromMaybe "" <$> (runX11Def Nothing getActiveWindow >>=
+                                       traverse defaultGetMenuLabel)
   markupEscapeText label (-1)
 
 truncatedGetActiveLabel :: Int -> TaffyIO T.Text
@@ -62,6 +64,9 @@ defaultWindowsConfig =
   , getActiveLabel = truncatedGetActiveLabel 35
   }
 
+instance Default WindowsConfig where
+  def = defaultWindowsConfig
+
 -- | Create a new Windows widget that will use the given Pager as
 -- its source of events.
 windowsNew :: WindowsConfig -> TaffyIO Gtk.Widget
@@ -74,7 +79,7 @@ windowsNew config = do
   subscription <-
     subscribeToPropertyEvents [ewmhActiveWindow, ewmhWMName, ewmhWMClass]
                       activeWindowUpdatedCallback
-  _ <- liftReader (Gtk.onWidgetUnrealize label) (unsubscribe subscription)
+  _ <- liftReader (\x -> Gtk.onWidgetUnrealize label x) (unsubscribe subscription)
 
   context <- ask
 
@@ -94,7 +99,8 @@ fillMenu config menu = ask >>= \context ->
     forM_ windowIds $ \windowId ->
       lift $ do
         labelText <- runReaderT (getMenuLabel config windowId) context
-        let focusCallback = runReaderT (runX11 $ focusWindow windowId) context >> return True
+        let focusCallback = runReaderT (runX11 $ focusWindow windowId) context >>
+                            return True
         item <- Gtk.menuItemNewWithLabel labelText
         _ <- Gtk.onWidgetButtonPressEvent item $ const focusCallback
         Gtk.menuShellAppend menu item
